@@ -242,6 +242,24 @@ Here's an example config file that shows them all in action::
 
 
 
+Automatic Control Socket Config
+~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+
+The supervisord and supervisorctl programs interact with each other via an
+XML-RPC control socket.  This provides a great deal of flexibility and control
+over security, but you have to configure it just so or things won't work.
+
+For convenience during development, django-supervisor provides automatic
+control socket configuration.  By default it binds the server to localhost
+on a fixed-but-randomish port, and sets up a username and password based on
+settings.SECRET_KEY.
+
+For production deployment, you might like to reconfigure this by setting up
+the [inet_http_server] or [unix_http_server] sections.  Django-supervisor
+will honour any such settings you provide.
+
+
+
 Autoreload
 ~~~~~~~~~~
 
@@ -264,6 +282,7 @@ option to supervisor or just exclude it in your project config file like so::
     exclude=true
 
 
+
 More Info
 ---------
 
@@ -275,7 +294,7 @@ first to make sure it all fits together the way I want...
 
 __ver_major__ = 0
 __ver_minor__ = 2
-__ver_patch__ = 0
+__ver_patch__ = 1
 __ver_sub__ = ""
 __version__ = "%d.%d.%d%s" % (__ver_major__,__ver_minor__,__ver_patch__,__ver_sub__)
 
